#  RustDesk-Server auf Portainer installieren


##  Voraussetzungen
- Ein Server mit **Docker** und **Portainer** installiert
- Ein öffentlicher oder privater **Domainname** (optional, aber empfohlen)
- Ports **21115-21119** in der Firewall freigegeben

---

## 🛠 Installation

### Erstelle einen neuen Stack in Portainer
1. **Melde dich bei Portainer an** und navigiere zu **Stacks**.
2. Klicke auf **"Add Stack"**.
3. Setze als Namen z.B. `rustdesk-server`.
4. Füge folgenden Docker-Compose-Code in das **Web-Editor-Feld** ein:

```yaml

services:
  hbbs:
    image: rustdesk/rustdesk-server:latest
    container_name: hbbs
    restart: always
    network_mode: "host"
    volumes:
      - ./data:/root
    command: ["hbbs"]

  hbbr:
    image: rustdesk/rustdesk-server:latest
    container_name: hbbr
    restart: always
    network_mode: "host"
    volumes:
      - ./data:/root
    command: ["hbbr"]
```

###  Erstelle den Stack
1. **Scrolle nach unten** und klicke auf **"Deploy the Stack"**.
2. Warte einige Sekunden, bis die Container gestartet wurden.

---

##  Konfiguration

###  Prüfe, ob der Server läuft
Gib folgendes auf der **Linux-Shell** deines Servers ein:

```sh
docker ps
```
Falls `hbbs` und `hbbr` als **running** angezeigt werden, läuft der Server.

###  Ports in der Firewall freigeben (falls nicht bereits geschehen)
Falls dein Server eine Firewall nutzt, stelle sicher, dass folgende Ports offen sind:

```sh
sudo ufw allow 21115:21119/tcp
sudo ufw allow 21116:21117/udp
sudo ufw reload
```

Falls du **firewalld** nutzt:

```sh
sudo firewall-cmd --add-port=21115-21119/tcp --permanent
sudo firewall-cmd --add-port=21116-21117/udp --permanent
sudo firewall-cmd --reload
```

---

##  Nutzung

### RustDesk-Client mit eigenem Server verbinden
1. Öffne den **RustDesk-Client**.
2. Gehe zu **Einstellungen > Netzwerk > Relay/ID-Server**.
3. Trage die **IP-Adresse oder Domain** deines Servers ein.
4. Speichere die Einstellungen.

Nun kannst du RustDesk mit deinem eigenen Server nutzen! 🎉

---

##  Fehlerbehebung

| Problem | Lösung |
|---------|--------|
| Container startet nicht | Prüfe `docker logs hbbs` oder `docker logs hbbr` |
| Verbindungsprobleme | Stelle sicher, dass die Ports geöffnet sind |
| RustDesk-Client kann sich nicht verbinden | Prüfe die IP-Adresse und Firewall-Einstellungen |

